# Copyright (C) 2023 - 2025 ANSYS, Inc. and/or its affiliates.
# SPDX-License-Identifier: MIT
#
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

from collections.abc import Sequence
from typing import Any, List, Optional, Union

from rocky30.process.cfd.cfd_coupling import CFDCouplingMode as CFDCouplingMode

from ansys.rocky.core._api_stubs.plugins10.plugins.api.api_element_item import (
    ApiElementItem,
)
from ansys.rocky.core._api_stubs.rocky30.plugins.api.ra_airflow import (
    RAAirFlow as RAAirFlow,
)
from ansys.rocky.core._api_stubs.rocky30.plugins.api.ra_grid_process_element import (
    RAGridProcessElementItem as RAGridProcessElementItem,
)
from ansys.rocky.core._api_stubs.rocky30.plugins.api.ra_semi_resolved_coupling import (
    RAFluentSemiResolvedCoupling as RAFluentSemiResolvedCoupling,
)
from ansys.rocky.core._api_stubs.rocky30.plugins.api.rocky_api_deprecated_decorator import (
    ApiDeprecated as ApiDeprecated,
)

class RACFDCoupling(ApiElementItem):
    @classmethod
    def GetWrappedClass(self): ...
    @classmethod
    def GetClassName(self): ...
    def SetupNoCoupling(self): ...
    def SetupAirFlow(self): ...
    def SetupOneWayLBM(self): ...
    def GetAirFlow(self): ...
    def GetOneWayLBM(self): ...
    def SetupFluentOneWaySteadyState(self, f2r_filename): ...
    def SetupOneWayFluentSteadyState(self, f2r_filename): ...
    def SetupOneWayFluent(self, f2r_filename): ...
    def SetupFluentTwoWay(self, cas_filename): ...
    def SetupTwoWayFluent(self, cas_filename): ...
    def SetupFluentTwoWaySemiResolved(self, cas_filename: str) -> Any: ...
    def SetupOneWayConstant(self): ...
    def SetupConstantOneWay(self): ...
    def SetupCFDConstantOneWayCouplingProcess(self): ...
    def GetCouplingMode(self): ...
    def GetCouplingProcess(self): ...
    def SetCurrentCouplingPartId(self) -> None: ...

class RABaseCFDCoupling(RAGridProcessElementItem):
    def GetCFDParametersList(self): ...
    def SetPartIdIfValid(self) -> None: ...
    def GetConvectiveHeatTransferLaw(self): ...
    def SetConvectiveHeatTransferLaw(self, value) -> None: ...
    def GetDragLaw(self): ...
    def SetDragLaw(self, value) -> None: ...
    def GetLiftLaw(self): ...
    def SetLiftLaw(self, value) -> None: ...
    def GetMorsiAndAlexanderK1(self): ...
    def SetMorsiAndAlexanderK1(self, value) -> None: ...
    def GetMorsiAndAlexanderK2(self): ...
    def SetMorsiAndAlexanderK2(self, value) -> None: ...
    def GetMorsiAndAlexanderK3(self): ...
    def SetMorsiAndAlexanderK3(self, value) -> None: ...
    def GetSyamlalObrienC1(self): ...
    def SetSyamlalObrienC1(self, value) -> None: ...
    def GetSyamlalObrienD1(self): ...
    def SetSyamlalObrienD1(self, value) -> None: ...
    def GetTorqueLaw(self): ...
    def SetTorqueLaw(self, value) -> None: ...
    def GetUseUserDefinedConstants(self): ...
    def SetUseUserDefinedConstants(self, value) -> None: ...
    def GetVirtualMassLaw(self): ...
    def SetVirtualMassLaw(self, value) -> None: ...

class RAConstantOneWayCoupling(RABaseCFDCoupling):
    @classmethod
    def GetWrappedClass(self): ...
    @classmethod
    def GetClassName(self): ...
    def GetDensity(self, unit: Optional[str] = ...) -> float: ...
    def SetDensity(self, value: Union[str, float], unit: Optional[str] = ...) -> None: ...
    def GetSpecificHeat(self, unit: Optional[str] = ...) -> float: ...
    def SetSpecificHeat(
        self, value: Union[str, float], unit: Optional[str] = ...
    ) -> None: ...
    def GetStartTime(self, unit: Optional[str] = ...) -> float: ...
    def SetStartTime(
        self, value: Union[str, float], unit: Optional[str] = ...
    ) -> None: ...
    def GetTemperature(self, unit: Optional[str] = ...) -> float: ...
    def SetTemperature(
        self, value: Union[str, float], unit: Optional[str] = ...
    ) -> None: ...
    def GetThermalConductivity(self, unit: Optional[str] = ...) -> float: ...
    def SetThermalConductivity(
        self, value: Union[str, float], unit: Optional[str] = ...
    ) -> None: ...
    def GetTurbulentDissipationRate(self, unit: Optional[str] = ...) -> float: ...
    def SetTurbulentDissipationRate(
        self, value: Union[str, float], unit: Optional[str] = ...
    ) -> None: ...
    def GetTurbulentKineticEnergy(self, unit: Optional[str] = ...) -> float: ...
    def SetTurbulentKineticEnergy(
        self, value: Union[str, float], unit: Optional[str] = ...
    ) -> None: ...
    def GetUseTurbulentDispersion(self) -> bool: ...
    def SetUseTurbulentDispersion(self, value: bool) -> None: ...
    def EnableTurbulentDispersion(self) -> None: ...
    def DisableTurbulentDispersion(self) -> None: ...
    def IsTurbulentDispersionEnabled(self) -> bool: ...
    def GetVelocity(self, unit: Optional[str] = ...) -> List[float]: ...
    def SetVelocity(
        self, values: Sequence[Union[str, float]], unit: Optional[str] = ...
    ) -> None: ...
    def GetViscosity(self, unit: Optional[str] = ...) -> float: ...
    def SetViscosity(
        self, value: Union[str, float], unit: Optional[str] = ...
    ) -> None: ...

RACFDCouplingTypes = Union[RAAirFlow, RABaseCFDCoupling, RAFluentSemiResolvedCoupling]
